StoredObject

Struct StoredObject 

pub struct StoredObject {
    pub uri: Rsync,
    pub hash: Option<ManifestHash>,
    pub content: Bytes,
}
The content of an object placed in the store.

This type collects all the data that is stored for regular objects of a publication point: the raw bytes of the object as well as its hash as stated on the publication point’s manifest. This hash is currently not used since we only store objects when we know the publication point was valid. It is retained here solely for compatibility with the existing stored object format.

Fields

uri: Rsync

The URI of the object.

hash: Option<ManifestHash>

The manifest hash of the object if available.

content: Bytes

The content of the object.

Implementations

Source

impl StoredObject

pub fn new(uri: Rsync, content: Bytes, hash: Option<ManifestHash>) -> Self

Creates a new stored object from its bytes and manifest hash.

pub fn read(reader: &mut impl Read) -> Result<Option<Self>, ParseError>

Reads a stored object from an IO reader.

pub fn write(&self, writer: &mut impl Write) -> Result<(), Error>

Appends the stored object to a writer.