pub struct StoredObject {
pub uri: Rsync,
pub hash: Option<ManifestHash>,
pub content: Bytes,
}Expand description
The content of an object placed in the store.
This type collects all the data that is stored for regular objects of a publication point: the raw bytes of the object as well as its hash as stated on the publication point’s manifest. This hash is currently not used since we only store objects when we know the publication point was valid. It is retained here solely for compatibility with the existing stored object format.
Fields
uri: RsyncThe URI of the object.
hash: Option<ManifestHash>The manifest hash of the object if available.
content: BytesThe content of the object.
Implementations
Sourceimpl StoredObject
impl StoredObject